@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Settings
- * @version    $Id: 130.webserver.php 928 2010-05-11 08:50:35Z d00p $
+ * @version    $Id: 130.webserver.php 1157 2010-06-21 08:38:13Z d00p $
  */
 
 return array(
@@ -33,6 +33,22 @@ return array(
 					'save_method' => 'storeSettingField',
 					'overview_option' => true
 					),
+				'system_httpuser' => array(
+					'label' => $lng['admin']['webserver_user'],
+					'settinggroup' => 'system',
+					'varname' => 'httpuser',
+					'type' => 'string',
+					'default' => 'www-data',
+					'save_method' => 'storeSettingField',
+					),
+				'system_httpgroup' => array(
+					'label' => $lng['admin']['webserver_group'],
+					'settinggroup' => 'system',
+					'varname' => 'httpgroup',
+					'type' => 'string',
+					'default' => 'www-data',
+					'save_method' => 'storeSettingField',
+					),
 				'system_apacheconf_vhost' => array(
 					'label' => $lng['serversettings']['apacheconf_vhost'],
 					'settinggroup' => 'system',
