@@ -12,7 +12,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Panel
- * @version    $Id: admin_updates.php 792 2010-04-14 07:36:38Z d00p $
+ * @version    $Id: admin_updates.php 857 2010-04-29 06:50:35Z d00p $
  */
 
 define('AREA', 'admin');
@@ -72,7 +72,7 @@ if($page == 'overview')
 	
 				include_once './install/updatesql.php';
 	
-				$redirect_url = 'admin_index.php';
+				$redirect_url = 'admin_index.php?s=' . $s;
 				eval("echo \"" . getTemplate("update/update_end") . "\";");
 	
 				updateCounters();
@@ -116,7 +116,7 @@ if($page == 'overview')
 		 */
 
 		$success_message = $lng['update']['noupdatesavail'];
-		$redirect_url = 'admin_index.php';
+		$redirect_url = 'admin_index.php?s=' . $s;
 		eval("echo \"" . getTemplate("update/noupdatesavail") . "\";");
 	}
 }
