@@ -12,7 +12,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Install
- * @version    $Id: update_0.9.inc.php 1086 2010-06-14 07:58:38Z EleRas $
+ * @version    $Id: update_0.9.inc.php 1175 2010-06-28 08:53:41Z d00p $
  */
 
 if(isFroxlorVersion('0.9-r0'))
@@ -795,4 +795,92 @@ if(isFroxlorVersion('0.9.9-svn1'))
 	updateToVersion('0.9.9');
 }
 
-?>
+if(isFroxlorVersion('0.9.9'))
+{
+	showUpdateStep("Updating from 0.9.9 to 0.9.10-svn1", false);
+	
+	showUpdateStep("Checking whether you are missing any settings", false);
+	$nonefound = true;
+	
+	$update_httpuser = isset($_POST['update_httpuser']) ? $_POST['update_httpuser'] : false;
+	$update_httpgroup = isset($_POST['update_httpgroup']) ? $_POST['update_httpgroup'] : false;
+
+	if($update_httpuser !== false)
+	{
+		$nonefound = false;
+		showUpdateStep("Adding missing setting 'httpuser'");
+		$db->query("INSERT INTO `" . TABLE_PANEL_SETTINGS . "` (`settinggroup`, `varname`, `value`) VALUES ('system', 'httpuser', '".$update_httpuser."');");
+		lastStepStatus(0);
+	}
+
+	if($update_httpgroup !== false)
+	{
+		$nonefound = false;
+		showUpdateStep("Adding missing setting 'httpgroup'");
+		$db->query("INSERT INTO `" . TABLE_PANEL_SETTINGS . "` (`settinggroup`, `varname`, `value`) VALUES ('system', 'httpgroup', '".$update_httpgroup."');");
+		lastStepStatus(0);
+	}
+
+	$result = $db->query_first("SELECT * FROM `" . TABLE_PANEL_SETTINGS . "` WHERE `settinggroup` = 'system' AND `varname` = 'debug_cron'");
+	if(!isset($result) || !isset($result['value']))
+	{
+		$nonefound = false;
+		showUpdateStep("Adding missing setting 'debug_cron'");
+		$db->query("INSERT INTO `" . TABLE_PANEL_SETTINGS . "` (`settinggroup`, `varname`, `value`) VALUES ('system', 'debug_cron', '0');");
+		lastStepStatus(0);
+	}
+	
+	if($nonefound) {
+		showUpdateStep("No missing settings found");
+		lastStepStatus(0);
+	}
+
+	updateToVersion('0.9.10-svn1');
+}
+
+if(isFroxlorVersion('0.9.10-svn1'))
+{
+	showUpdateStep("Updating from 0.9.10-svn1 to 0.9.10-svn2", false);
+	
+	showUpdateStep("Updating database table definition for panel_databases");
+	$db->query("ALTER TABLE `" . TABLE_PANEL_DATABASES . "` ADD `apsdb` tinyint(1) NOT NULL default '0' AFTER `dbserver`;");
+	lastStepStatus(0);
+
+	showUpdateStep("Adding APS databases to customers overview");
+	$count_dbupdates = 0;
+	$db_root = null;
+	openRootDB();
+	$result = $db_root->query("SHOW DATABASES;");
+	while($row = $db_root->fetch_array($result))
+	{	
+		if(preg_match('/^web([0-9]+)aps([0-9]+)$/', $row['Database'], $matches))
+		{
+			$cid = $matches[1];
+			$databasedescription = 'APS DB';
+			$result = $db->query('INSERT INTO `' . TABLE_PANEL_DATABASES . '` (`customerid`, `databasename`, `description`, `dbserver`, `apsdb`) VALUES ("' . (int)$cid . '", "' . $db->escape($row['Database']) . '", "' . $db->escape($databasedescription) . '", "0", "1")');
+			$result = $db->query('UPDATE `' . TABLE_PANEL_CUSTOMERS . '` SET `mysqls_used`=`mysqls_used`+1 WHERE `customerid`="' . (int)$cid . '"');
+			$count_dbupdates++;
+		}
+	}
+	closeRootDB();
+	if($count_dbupdates > 0) {
+		lastStepStatus(0, "Found ".$count_dbupdates." customer APS databases");
+	} else {
+		lastStepStatus(0, "None found");
+	}
+
+	updateToVersion('0.9.10-svn2');
+}
+
+if(isFroxlorVersion('0.9.10-svn2'))
+{
+	showUpdateStep("Updating from 0.9.10-svn2 to 0.9.10", false);
+
+	$update_directlyviahostname = isset($_POST['update_directlyviahostname']) ? '1' : '0';
+
+	showUpdateStep("Adding new settings");
+	$db->query("INSERT INTO `" . TABLE_PANEL_SETTINGS . "` (`settinggroup`, `varname`, `value`) VALUES ('system', 'froxlordirectlyviahostname', '".(int)$update_directlyviahostname."');");
+	lastStepStatus(0);
+
+	updateToVersion('0.9.10');
+}
