@@ -12,7 +12,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Language
- * @version    $Id: preconfig_0.9.inc.php 1045 2010-06-02 10:08:01Z d00p $
+ * @version    $Id: preconfig_0.9.inc.php 1175 2010-06-28 08:53:41Z d00p $
  */
 
 /**
@@ -158,4 +158,66 @@ function parseAndOutputPreconfig(&$has_preconfig, &$return, $current_version)
 		$question.= makeyesno('update_defdns_mailentry', '1', '0', '0');
 		eval("\$return.=\"" . getTemplate("update/preconfigitem") . "\";");
 	}
+	
+	if(versionInUpdate($current_version, '0.9.10-svn1'))
+	{
+		$has_nouser = false;
+		$has_nogroup = false;
+
+		$result = $db->query_first("SELECT * FROM `" . TABLE_PANEL_SETTINGS . "` WHERE `settinggroup` = 'system' AND `varname` = 'httpuser'");
+		if(!isset($result) || !isset($result['value']))
+		{
+			$has_preconfig = true;
+			$has_nouser = true;
+			$guessed_user = 'www-data';
+			if(function_exists('posix_getuid')
+				&& function_exists('posix_getpwuid')
+			) {
+				$_httpuser = posix_getpwuid(posix_getuid());
+				$guessed_user = $_httpuser['name'];
+			}
+		}
+		
+		$result = $db->query_first("SELECT * FROM `" . TABLE_PANEL_SETTINGS . "` WHERE `settinggroup` = 'system' AND `varname` = 'httpgroup'");
+		if(!isset($result) || !isset($result['value']))
+		{
+			$has_preconfig = true;
+			$has_nogroup = true;
+			$guessed_group = 'www-data';
+			if(function_exists('posix_getgid')
+				&& function_exists('posix_getgrgid')
+			) {
+				$_httpgroup = posix_getgrgid(posix_getgid());
+				$guessed_group = $_httpgroup['name'];
+			}
+		}
+
+		if($has_nouser || $has_nogroup)
+		{
+			$description = 'Please enter the correct username/groupname of the webserver on your system We\'re guessing the user but it might not be correct, so please check.';
+			if($has_nouser)
+			{
+				$question = '<strong>Please enter the webservers username:</strong>&nbsp;<input type="text" class="text" name="update_httpuser" value="'.$guessed_user.'" />';
+			} 
+			elseif($has_nogroup) 
+			{
+				$question2 = '<strong>Please enter the webservers groupname:</strong>&nbsp;<input type="text" class="text" name="update_httpgroup" value="'.$guessed_group.'" />';
+				if($has_nouser) {
+					$question .= '<br /><br />'.$question2;
+				} else {
+					$question = $question2;
+				}
+			}
+			eval("\$return.=\"" . getTemplate("update/preconfigitem") . "\";");
+		}
+	}
+
+	if(versionInUpdate($current_version, '0.9.10'))
+	{
+		$has_preconfig = true;
+		$description = 'you can now decide whether Froxlor should be reached via hostname/froxlor or directly via the hostname.';
+		$question = '<strong>Do you want Froxlor to be reached directly via the hostname?:</strong>&nbsp;';
+		$question.= makeyesno('update_directlyviahostname', '1', '0', '0');
+		eval("\$return.=\"" . getTemplate("update/preconfigitem") . "\";");
+	}
 }
