@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Configfiles
- * @version    $Id: hardy.inc.php 1048 2010-06-07 11:14:49Z d00p $
+ * @version    $Id: hardy.inc.php 1126 2010-06-16 11:34:48Z d00p $
  */
 
 return Array(
@@ -297,7 +297,7 @@ return Array(
 						'label' => 'Awstats',
 						'commands' => Array(
 							'apt-get install awstats',
-							'cp /usr/share/doc/awstats/examples/awstats_buildstaticpages.pl /usr/lib/cgi-bin/',
+							'cp /usr/share/doc/awstats/examples/awstats_buildstaticpages.pl '.makeCorrectDir($settings['system']['awstats_path']),
 							'mv '.makeCorrectFile($settings['system']['awstats_conf'].'/awstats.conf').' '.makeCorrectFile($settings['system']['awstats_conf'].'/awstats.model.conf'),
 							'sed -i.bak \'s/^DirData/# DirData/\' '.makeCorrectFile($settings['system']['awstats_conf'].'/awstats.model.conf')
 						),
