@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Functions
- * @version    $Id: function.isConfigDir.php 138 2010-01-27 08:54:31Z Dessa $
+ * @version    $Id: function.isConfigDir.php 848 2010-04-28 07:04:01Z d00p $
  */
 
 /**
@@ -27,7 +27,7 @@
  * @author Florian Lippert <flo@syscp.org>
  */
 
-function isConfigDir($dir)
+function isConfigDir($dir, $ifexists = false)
 {
 	if(file_exists($dir))
 	{
@@ -42,9 +42,16 @@ function isConfigDir($dir)
 	}
 	else
 	{
-		if(substr($dir, -1) == '/')
+		if(!$ifexists)
 		{
-			$returnval = true;
+			if(substr($dir, -1) == '/')
+			{
+				$returnval = true;
+			}
+			else
+			{
+				$returnval = false;
+			}
 		}
 		else
 		{
