@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    System
- * @version    $Id: init.php 870 2010-05-03 11:47:06Z d00p $
+ * @version    $Id: init.php 1139 2010-06-16 20:13:12Z EleRas $
  */
 
 // prevent Froxlor pages from being cached
@@ -265,22 +265,30 @@ foreach($langs as $key => $value)
 	$languages[$key] = $key;
 }
 
-if(!isset($userinfo['def_language'])
-   || !isset($languages[$userinfo['def_language']]))
+if (isset($userinfo['language']) && isset($languages[$userinfo['language']]))
 {
-	if(isset($_GET['language'])
-	   && isset($languages[$_GET['language']]))
-	{
-		$language = $_GET['language'];
-	}
-	else
-	{
-		$language = $settings['panel']['standardlanguage'];
-	}
+	// default: use language from session, #277
+	$language = $userinfo['language'];
 }
 else
 {
-	$language = $userinfo['def_language'];
+	if(!isset($userinfo['def_language'])
+	   || !isset($languages[$userinfo['def_language']]))
+	{
+		if(isset($_GET['language'])
+		   && isset($languages[$_GET['language']]))
+		{
+			$language = $_GET['language'];
+		}
+		else
+		{
+			$language = $settings['panel']['standardlanguage'];
+		}
+	}
+	else
+	{
+		$language = $userinfo['def_language'];
+	}
 }
 
 // include every english language file we can get
