@@ -14,7 +14,7 @@
  * @author     Froxlor Team <team@froxlor.org>
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Language
- * @version    $Id: english.lng.php 1087 2010-06-14 08:09:17Z d00p $
+ * @version    $Id: english.lng.php 1175 2010-06-28 08:53:41Z d00p $
  */
 
 /**
@@ -1427,4 +1427,14 @@ $lng['error']['exception'] = '%s';
 // ADDED IN FROXLOR 0.9.9-svn1
 $lng['serversettings']['mail_also_with_mxservers'] = 'Create mail-, imap-, pop3- and smtp-"A record" also with MX-Servers set';
 
+// ADDED IN FROXLOR 0.9.10-svn1
+$lng['aps']['nocontingent'] = 'Your APS contingent is insufficient. You cannot install any package.';
+$lng['aps']['packageneedsdb'] = 'This package needs a database but your contingent is used up';
+$lng['aps']['cannoteditordeleteapsdb'] = 'APS databases cannot be edited or removed here';
+$lng['admin']['webserver_user'] = 'Webserver user-name';
+$lng['admin']['webserver_group'] = 'Webserver group-name';
+
+// ADDED IN FROXLOR 0.9.10
+$lng['serversettings']['froxlordirectlyviahostname'] = 'Access Froxlor directly via the hostname';
+
 ?>
