@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Cron
- * @version    $Id: cron_tasks.inc.http.10.apache.php 1046 2010-06-04 05:50:23Z d00p $
+ * @version    $Id: cron_tasks.inc.http.10.apache.php 1175 2010-06-28 08:53:41Z d00p $
  */
 
 if(@php_sapi_name() != 'cli'
@@ -81,9 +81,9 @@ class apache
 			// if we use fcgid we don't need this file
 			if(file_exists($vhosts_filename))
 			{
-				fwrite($this->debugHandler, '  apache::_createStandardDirectoryEntry: unlinking ' . basename($vhost_filename) . "\n");
-				$this->logger->logAction(CRON_ACTION, LOG_NOTICE, 'unlinking ' . basename($vhost_filename));
-				unlink(makeCorrectFile($vhost_filename));
+				fwrite($this->debugHandler, '  apache::_createStandardDirectoryEntry: unlinking ' . basename($vhosts_filename) . "\n");
+				$this->logger->logAction(CRON_ACTION, LOG_NOTICE, 'unlinking ' . basename($vhosts_filename));
+				unlink(makeCorrectFile($vhosts_filename));
 			}			
 		}
 		else
@@ -192,7 +192,14 @@ class apache
 				/**
 				 * add 'real'-vhost content here, like doc-root :)
 				 */
-				$mypath = makeCorrectDir(dirname(dirname(dirname(dirname(__FILE__)))));
+				if($this->settings['system']['froxlordirectlyviahostname'])
+				{
+					$mypath = makeCorrectDir(dirname(dirname(dirname(__FILE__))));
+				}
+				else 
+				{
+					$mypath = makeCorrectDir(dirname(dirname(dirname(dirname(__FILE__)))));
+				}
 				$this->virtualhosts_data[$vhosts_filename].= 'DocumentRoot "'.$mypath.'"'."\n";
 				
 				if($row_ipsandports['vhostcontainer_servername_statement'] == '1')
